==> sponge-api-1.14.0-sources.jar: org/openksavi/sponge/action/ActionAdapter.java <==
/*
 * Copyright 2016-2017 The Sponge authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.openksavi.sponge.action;

import java.util.Map;
import java.util.Set;

import org.openksavi.sponge.ProcessorAdapter;
import org.openksavi.sponge.type.provided.ProvidedValue;

/**
 * Action adapter.
 */
public interface ActionAdapter extends ProcessorAdapter<Action>, ActionOperations {

    /**
     * Informs if the action in a given context is active.
     *
     * @param context the context.
     * @return {@code true} if the action is active.
     */
    boolean isActive(IsActionActiveContext context);

    /**
     * Provides action arguments. Submits arguments and/or returns provided values along with value sets.
     *
     * @param parameters the parameters.
     * @return the map of argument names and values (value sets).
     */
    Map<String, ProvidedValue<?>> provideArgs(ProvideArgsParameters parameters);

    /**
     * Returns the registered type names used in this action.
     *
     * @return the registered type names.
     */
    Set<String> getRegisteredTypeNames();
}

==> sponge-api-1.15.0-sources.jar: org/openksavi/sponge/action/ActionAdapter.java <==
/*
 * Copyright 2016-2017 The Sponge authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.openksavi.sponge.action;

import java.util.Map;
import java.util.Set;

import org.openksavi.sponge.ProcessorAdapter;
import org.openksavi.sponge.type.provided.ProvidedValue;

/**
 * Action adapter.
 */
public interface ActionAdapter extends ProcessorAdapter<Action>, ActionOperations {

    /**
     * Informs if the action in a given context is active. This method always returns {@code true} if the action is not activatable.
     *
     * @param context the context.
     * @return {@code true} if the action is active.
     */
    boolean isActive(IsActionActiveContext context);

    /**
     * Provides action arguments. Submits arguments and/or returns provided values along with value sets.
     *
     * @param parameters the parameters.
     * @return the map of argument names and values (value sets).
     */
    Map<String, ProvidedValue<?>> provideArgs(ProvideArgsParameters parameters);

    /**
     * Returns the registered type names used in this action.
     *
     * @return the registered type names.
     */
    Set<String> getRegisteredTypeNames();
}
